pro civ_subtract, index, data,  $
                  iout, dout, $
                  err   = err, $
                  debug = debug
;+
; NAME:
;    CIV_SUBTRACT.PRO
;
; PURPOSE:
;    Given an arbitrary set of UV images from TRACE out of the 
;    1550, 1600 and 1700 Images, generate a "Clean" C IV image, 
;    per Handy et al. (1998) Solar Physics, in press.
;
;    Note that unlike Handy et al., this routine also includes 
;    a capability to extract CIV images from any arbitrary pair of
;    UV images.  This has not yet been fully investigated, and the 
;    uncertainty in these measurements is pretty suspect.
;
; CALLING SEQUENCE:
;    civ_subtract, index, data, iout, dout [,err=err][,/debug]
; 
; INPUTS:
;    index, data -- data cube for the pair/triplet of images
;                   (data cube is expected to be correlated, images 
;                   are expected to be the same size, but order of 
;                   images (out of 1550, 1600, 1700) is arbitrary
;
; KEYWORD PARAMETERS:
;    debug       -- Gives small, less-than-useful hints as to what's 
;                   going on.
;
; OUTPUTS:
;    iout, dout  -- index and data element of C IV image.  The units 
;                   of dout are photons/s/cm^2/Sr.  iout is currently
;                   a copy of the index structure of the 1550 image, or
;                   the 1600 image if 1550 isn't used.
;
; OPTIONAL OUTPUTS:
;    err         -- The predicted error of the image  (tbd)
;
; TO DO:
;    Which images (and their dates, and other information) needs to be 
;    included in the history of the returned index structure.
;
; MODIFICATION HISTORY:
;    19-Jul-98 - (BNH) - Written
;    24-Jul-98 - (BNH) - Do the image normalization here.  That seems to
;                        be the method of least surprise.  Also fix one
;                        typo.
;     3-Aug-98 - (BNH) - Use 'index' everwhere to fix exposure normalization.
;
;
; $Id: civ_subtract.pro,v 1.6 1998/07/24 16:50:09 handy Exp $
;-

; Constants
i2c_corr =  1.07
ss_1550 = where(index.wave_len eq '1550')
ss_1600 = where(index.wave_len eq '1600')
ss_1700 = where(index.wave_len eq '1700')

;; 
;; Determine which set of coefficients to use
;;
case 1 of
    ;; Normal Case:  Three images, 1550, 1600, 1700
    ((ss_1550[0] ge 0) and (ss_1600[0] ge 0) and (ss_1700[0] ge 0)): begin
        if keyword_set(debug) then $
          message, /info, 'Using 1550/1600/1700 image set.'
        i1 = data[*,*,ss_1550]/index[ss_1550].sht_mdur
        i2 = data[*,*,ss_1600]/index[ss_1600].sht_mdur - $
             data[*,*,ss_1700]/index[ss_1700].sht_mdur * i2c_corr
        iout = index[ss_1550]

        alpha =  1.55e13
        beta  = -1.09e12
    end

    ;; 1550 and 1600 Images
    ((ss_1550[0] ge 0) and (ss_1600[0] ge 0) and (ss_1700[0] lt 0)): begin
        if keyword_set(debug) then $
          message, /info, 'Using 1550/1600 image set.'
        i1 = data[*,*,ss_1550]/index[ss_1550].sht_mdur
        i2 = data[*,*,ss_1600]/index[ss_1600].sht_mdur
        iout = index[ss_1550]

        alpha =  1.56e13
        beta  = -1.09e12
    end

    ;; 1550 and 1700 Images
    ((ss_1550[0] ge 0)and (ss_1600[0] lt 0) and (ss_1700[0] ge 0)): begin
        if keyword_set(debug) then $
          message, /info, 'Using 1550/1700 image set.'
        i1 = data[*,*,ss_1550]/index[ss_1550].sht_mdur
        i2 = data[*,*,ss_1700]/index[ss_1700].sht_mdur
        iout = index[ss_1550]

        alpha =  1.32e13
        beta  = -7.28e11
    end

    ;; 1600 and 1700 Images
    ((ss_1550[0] lt 0) and (ss_1600[0] ge 0) and (ss_1700[0] ge 0)): begin
        if keyword_set(debug) then $
          message, /info, 'Using 1600/1700 image set.'
        i1 = data[*,*,ss_1600]/index[ss_1600].sht_mdur
        i2 = data[*,*,ss_1700]/index[ss_1700].sht_mdur
        iout = index[ss_1600]

        alpha =  1.33e12
        beta  = -6.60e12
    end

    else:  message, 'Insufficient data cube.'

endcase

dout = (alpha * i1) + (beta * i2)

iout.wave_len = 'C IV'

return
end
